@@ -15,7 +15,7 @@ class Extractor(QtCore.QObject):
       QtCore.QObject.__init__(self)
 
       self.url = ''
-      self.stats = 'http://gerald.fauvelle.free.fr/stats/stats.php?ttid=%s&error=%s&url=%s'
+      self.report = 'http://gerald.fauvelle.free.fr/traintrain/report.php?ttid=%s&error=%s&url=%s'
       
       self.userAgent = 'Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
       self.urlPerturb = ''
@@ -190,9 +190,9 @@ class Extractor(QtCore.QObject):
          DebugFile(self.html, 'html_%s.html'%self.id)
          error = self.html
          
-      requestStats = QNetworkRequest( QtCore.QUrl(self.stats%(self.model.ttConf.ttid, error, self.url)) )
-      requestStats.setRawHeader("User-Agent", self.userAgent)
-      reply = self.manager2.get(requestStats)
+      requestReport = QNetworkRequest( QtCore.QUrl(self.report%(self.model.ttConf.ttid, error, self.url)) )
+      requestReport.setRawHeader("User-Agent", self.userAgent)
+      reply = self.manager2.get(requestReport)
       
       cpt = 0
       for ride in self.listRides:
