@@ -34,7 +34,10 @@ class TableParserTransilien(Extractor, HTMLParser.HTMLParser):
       if tag == 'table' and dict(attrs).has_key('id') and (dict(attrs)['id'] == 'listeTrain'):
          self.tagTableHoraires = True
 
-      elif dict(attrs).has_key('id') and dict(attrs)['id']=='message':
+      elif dict(attrs).has_key('id') and (
+            dict(attrs)['id']=='message' or 
+            ( dict(attrs)['id']=='icv' and dict(attrs).has_key('class') and dict(attrs)['class']=='listeICVPair')
+            ):
          DebugLog("  Error found!")
          self.tagError = True
 
@@ -129,7 +132,7 @@ class TableParserTransilien(Extractor, HTMLParser.HTMLParser):
       
 class ExtractorTransilien(TableParserTransilien):
    def __init__(self, ligne):
-      DebugLog("ExtractorTransilien::Init")
+      DebugLog("ExtractorTransilien::__init__")
 
       Extractor.__init__(self, ligne.id)
 
