@@ -67,13 +67,15 @@ class RideModel(QtCore.QObject):
 
    def getUrl(self):
       t, l, s = self.icon
-      rul = ''
+      url = ''
       if t=='M':
          url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_métro_de_Paris"%l
       elif t=='R':
          url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_RER_d'Ile-de-France"%l
       elif t=='T':
          url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_tramway_d'Île-de-France"%l
+      elif t=='TR':
+         url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_Transilien"%l
 
       return QtCore.QUrl(url)
 
